call method
Validates whether a value ends with the specified pattern.
This method checks if the input value ends with the specified pattern. If
the value does not end with the pattern, an error message is generated using
the buildMessage method.
Parameters:
attribute: The identifier of the form attribute being validated.value: The value to be validated.
Returns:
A validation error message if the value does not end with the specified pattern,
or null if the value is valid.
Implementation
@override
String? call(String attribute, String value) {
if (value.isNotEmpty) {
if (!value.endsWith(pattern)) {
return buildMessage(attribute, value, onExtra: (message) {
message.replaceAll(':pattern', pattern);
return message;
});
}
}
return null;
}