call abstract method
Validates a field value and returns an error message if validation fails, or null if it succeeds.
This method should be implemented in concrete validation rule classes to define the validation logic.
Parameters:
attribute: The identifier of the form attribute being validated.value: The value to be validated.
Returns:
A validation error message if the validation fails, or null if the validation succeeds.
Implementation
String? call(String attribute, String value);